using System.Security.Cryptography;
using System.Text;
using System.Text.Json.Serialization;
using FitConnect.Models.Api.Metadata;

namespace FitConnect.Models;

public class Attachment {
    public string Id { get; init; }

    public byte[]? Content { get; init; }

    public string? Hash => CalculateHash();

    public string? Filename { get; init; }

    public string? Purpose { get; init; }

    public string? MimeType { get; init; }

    public string? Description { get; init; }

    public AttachmentSignature? Signature => GenerateSignature();

    private AttachmentSignature GenerateSignature() {
        return new AttachmentSignature {
            SignatureFormat = SignatureFormat.Pdf,
            DetachedSignature = true,
        };
    }

    private string CalculateHash() {
        return ByteToHexString(SHA512.Create().ComputeHash(Content));
    }

    private string ByteToHexString(byte[] data) {
        StringBuilder sb = new StringBuilder();
        foreach (byte b in data) {
            sb.Append(b.ToString("x2"));
        }

        return sb.ToString();
    }
}
